@@ -10,6 +10,9 @@ from dm.view.registry import RegistrySearchView
 from dm.view.registry import RegistryFindView
 from dm.view.registry import RegistryUpdateView
 from dm.view.registry import RegistryDeleteView
+from quant.contracttype.simple import Contract 
+
+# Todo: Set navigation for extension contract types.
 
 class SymbolNavigation(RegistryNavigation):
 
@@ -30,10 +33,10 @@ class SymbolNavigation(RegistryNavigation):
         return items
 
 
-class ModelNavigation(RegistryNavigation):
+class CodesNavigation(RegistryNavigation):
 
     def createMajorItem(self):
-        return '/models/'
+        return '/codes/'
 
     def createMinorItem(self):
         return ''
@@ -41,14 +44,35 @@ class ModelNavigation(RegistryNavigation):
     def createMinorItems(self):
         items = []
         items.append(
-            {'title': 'Index', 'url': '/models/'}
+            {'title': 'Price processes', 'url': '/priceProcesses/'}
         )
         items.append(
-            {'title': 'New', 'url': '/models/create/'}
+            {'title': 'Contract types', 'url': '/contractTypes/'}
+        )
+        items.append(
+            {'title': 'Pricers', 'url': '/pricers/'}
         )
         return items
 
 
+class ContractTypeNavigation(CodesNavigation):
+
+    def createMinorItem(self):
+        return '/contractTypes/'
+
+
+class PricerNavigation(CodesNavigation):
+
+    def createMinorItem(self):
+        return '/pricers/'
+
+
+class PriceProcessNavigation(CodesNavigation):
+
+    def createMinorItem(self):
+        return '/priceProcesses/'
+
+
 class ImageNavigation(RegistryNavigation):
 
     def createMajorItem(self):
@@ -68,10 +92,10 @@ class ImageNavigation(RegistryNavigation):
         return items
 
 
-class DeliveryPeriodNavigation(RegistryNavigation):
+class MarketNavigation(RegistryNavigation):
 
     def createMajorItem(self):
-        return '/deliveryPeriods/'
+        return '/markets/'
 
     def createMinorItem(self):
         return ''
@@ -79,68 +103,31 @@ class DeliveryPeriodNavigation(RegistryNavigation):
     def createMinorItems(self):
         items = []
         items.append(
-            {'title': 'Index', 'url': '/deliveryPeriods/'}
+            {'title': 'Index', 'url': '/markets/'}
         )
         items.append(
-            {'title': 'New', 'url': '/deliveryPeriods/create/'}
+            {'title': 'New', 'url': '/markets/create/'}
         )
         return items
 
 
-class EuropeanNavigation(RegistryNavigation):
+class TradesNavigation(RegistryNavigation):
 
     def createMajorItem(self):
-        return '/europeans/'
+        return '/trades/'
 
     def createMinorItem(self):
-        return ''
+        return '/%s/' % self.view.getManipulatedObjectRegister().getDomainClass().getRegistryAttrName()
 
     def createMinorItems(self):
         items = []
-        items.append(
-            {'title': 'Index', 'url': '/europeans/'}
-        )
-        items.append(
-            {'title': 'New', 'url': '/europeans/create/'}
-        )
-        return items
-
-
-class AmericanNavigation(RegistryNavigation):
-
-    def createMajorItem(self):
-        return '/americans/'
-
-    def createMinorItem(self):
-        return ''
-
-    def createMinorItems(self):
-        items = []
-        items.append(
-            {'title': 'Index', 'url': '/americans/'}
-        )
-        items.append(
-            {'title': 'New', 'url': '/americans/create/'}
-        )
-        return items
-
-
-class PricerNavigation(RegistryNavigation):
-
-    def createMajorItem(self):
-        return '/pricers/'
-
-    def createMinorItem(self):
-        return ''
-
-    def createMinorItems(self):
-        items = []
-        items.append(
-            {'title': 'Index', 'url': '/pricers/'}
-        )
-        items.append(
-            {'title': 'New', 'url': '/pricers/create/'}
-        )
+        for contractType in self.view.registry.contractTypes:
+            if contractType.canImportCode():
+                registryAttrName = contractType.getExtensionRegistryAttrName()
+                items.append({
+                    'title': registryAttrName.capitalize(),
+                    'url': '/%s/' % registryAttrName
+                })
         return items
 
 
@@ -197,31 +184,31 @@ class QuantRegistryView(RegistryView, QuantView):
         'symbols/read':   SymbolNavigation,
         'symbols/update': SymbolNavigation,
         'symbols/delete': SymbolNavigation,
-        'models/list':   ModelNavigation,
-        'models/create': ModelNavigation,
-        'models/read':   ModelNavigation,
-        'models/update': ModelNavigation,
-        'models/delete': ModelNavigation,
+        'priceProcesses/list':   PriceProcessNavigation,
+        'priceProcesses/create': PriceProcessNavigation,
+        'priceProcesses/read':   PriceProcessNavigation,
+        'priceProcesses/update': PriceProcessNavigation,
+        'priceProcesses/delete': PriceProcessNavigation,
+        'contractTypes/list':   ContractTypeNavigation,
+        'contractTypes/create': ContractTypeNavigation,
+        'contractTypes/read':   ContractTypeNavigation,
+        'contractTypes/update': ContractTypeNavigation,
+        'contractTypes/delete': ContractTypeNavigation,
         'images/list':   ImageNavigation,
         'images/create': ImageNavigation,
         'images/read':   ImageNavigation,
         'images/update': ImageNavigation,
         'images/delete': ImageNavigation,
-        'deliveryPeriods/list':   DeliveryPeriodNavigation,
-        'deliveryPeriods/create': DeliveryPeriodNavigation,
-        'deliveryPeriods/read':   DeliveryPeriodNavigation,
-        'deliveryPeriods/update': DeliveryPeriodNavigation,
-        'deliveryPeriods/delete': DeliveryPeriodNavigation,
-        'europeans/list':   EuropeanNavigation,
-        'europeans/create': EuropeanNavigation,
-        'europeans/read':   EuropeanNavigation,
-        'europeans/update': EuropeanNavigation,
-        'europeans/delete': EuropeanNavigation,
-        'americans/list':   AmericanNavigation,
-        'americans/create': AmericanNavigation,
-        'americans/read':   AmericanNavigation,
-        'americans/update': AmericanNavigation,
-        'americans/delete': AmericanNavigation,
+        'markets/list':   MarketNavigation,
+        'markets/create': MarketNavigation,
+        'markets/read':   MarketNavigation,
+        'markets/update': MarketNavigation,
+        'markets/delete': MarketNavigation,
+        'trades/list':   TradesNavigation,
+        'trades/create': TradesNavigation,
+        'trades/read':   TradesNavigation,
+        'trades/update': TradesNavigation,
+        'trades/delete': TradesNavigation,
         'pricers/list':   PricerNavigation,
         'pricers/create': PricerNavigation,
         'pricers/read':   PricerNavigation,
@@ -241,6 +228,14 @@ class QuantRegistryView(RegistryView, QuantView):
     contextSetters = {
     }
 
+    def getViewPosition(self):
+        domainClass = self.getManipulatedObjectRegister().getDomainClass()
+        if issubclass(domainClass, Contract):
+            viewPosition = 'trades/' + self.getTemplatePathActionName()
+        else:
+            viewPosition = super(QuantRegistryView, self).getViewPosition()
+        return viewPosition
+
 
 class QuantRegistryListView(QuantRegistryView, RegistryListView):
     pass
