@@ -1,6 +1,18 @@
 from django.conf.urls.defaults import *
 import re
 import quant.regexps
+from quant.soleInstance import application
+
+contractAttrNames = []
+for contractType in application.registry.contractTypes:
+    try:
+        attrName = contractType.getExtensionRegistryAttrName()
+    except ImportError:
+        pass
+    else:
+        contractAttrNames.append(attrName)
+
+contractpattern = '|'.join(contractAttrNames)
 
 urlpatterns = patterns('quant.django.apps.eui.views',
 
@@ -23,6 +35,18 @@ urlpatterns = patterns('quant.django.apps.eui.views',
     (r'^help/$',
         'welcome.welcome'),
 
+    #
+    ##  Trades Page
+
+    (r'^trades/$',
+        'welcome.trades'),
+
+    #
+    ##  Codes Page
+
+    (r'^codes/$',
+        'welcome.codes'),
+
     #
     ##  User Authentication
 
@@ -131,13 +155,13 @@ urlpatterns = patterns('quant.django.apps.eui.views',
     #
     ## Registry views
 
-    (r'^(?P<registryPath>(symbols|europeans|americans|pricers|books|models|images|deliveryPeriods|results).*)/(?P<actionName>(find))/(?P<actionValue>[\w\d]*)/$',
+    (r'^(?P<registryPath>(symbols|markets|priceProcesses|contractTypes|pricers|'+contractpattern+r'|books|images|results)(/.*)?)/(?P<actionName>(find))/(?P<actionValue>[\w\d]*)/$',
         'registry.view'),
 
-    (r'^(?P<registryPath>(symbols|europeans|americans|pricers|books|models|images|deliveryPeriods|results).*)/(?P<actionName>(create|update|delete|read|search|undelete|purge))/$',
+    (r'^(?P<registryPath>(symbols|markets|priceProcesses|contractTypes|pricers|'+contractpattern+r'|books|images|results)(/.*)?)/(?P<actionName>(create|update|delete|read|search|undelete|purge))/$',
         'registry.view'),
 
-    (r'^(?P<registryPath>(symbols|europeans|americans|pricers|books|models|images|deliveryPeriods|results).*)/$',
+    (r'^(?P<registryPath>(symbols|markets|priceProcesses|contractTypes|pricers|'+contractpattern+r'|books|images|results)(/.*)?)/$',
         'registry.view'),
 
 
