@@ -5,19 +5,20 @@ class Book(SimpleObject):
     isUnique = False
 
     title = String()
-    model = HasA('Model')
     results = AggregatesMany('Result', key='id')
-    europeans = HasMany('European', key='id')
-    americans = HasMany('American', key='id')
 
     def getLabelValue(self):
         return self.title or self.id
 
     def getContracts(self):
-        return list(self.europeans) + list(self.americans)
+        contracts = []
+        for contractType in self.registry.contractTypes:
+            register = contractType.getCodeClass().createRegister()
+            contracts += register.findDomainObjects(book=self)
+        return contracts
 
     def countContracts(self):
-        return len(self.europeans) + len(self.americans)
+        return len(self.getContracts())
 
     def delete(self):
         for contract in self.getContracts():
