@@ -10,14 +10,16 @@ def suite():
 
 class TestModel(TestCase):
 
-    observationTime = datetime.datetime(2010, 1, 1)
+    now = datetime.datetime.now()
+    thisYear = now.year
+    thisMonth = now.month
+    thisDay = now.day
+    observationTime = datetime.datetime(thisYear, thisMonth, thisDay)
 
     def setUp(self):
-        self.model = self.registry.models.read(title='WTI (Mock)')
-        self.image = self.model.images.read(observationTime=self.observationTime)
+        self.image = self.registry.images.read(observationTime=self.observationTime)
 
     def test_model(self):
-        self.assertTrue(self.model)
         self.assertTrue(self.image)
 
 
