@@ -10,11 +10,14 @@ def suite():
 
 class TestResult(TestCase):
 
-    observationTime = datetime.datetime(2010, 1, 1)
+    now = datetime.datetime.now()
+    thisYear = now.year
+    thisMonth = now.month
+    thisDay = now.day
+    observationTime = datetime.datetime(thisYear, thisMonth, thisDay)
 
     def setUp(self):
-        self.model = self.registry.models.read(title='WTI (Mock)')
-        self.image = self.model.images.read(observationTime=self.observationTime)
+        self.image = self.registry.images.read(observationTime=self.observationTime)
         self.book = self.registry.books.read(title='My Book')
         self.result = self.registry.results.create(book=self.book, image=self.image)
 
