@@ -9,11 +9,11 @@ from quant.pricer.base import AbstractOptionPricer
 class EuropeanBlackScholesPricer(AbstractOptionPricer):
 
     def calcPrice(self):
-        S = float(self.currentPrice)
+        S = float(self.lastPrice)
         K = float(self.strikePrice)
         r = float(self.annualRiskFreeRate) / 100.0
         t = float(self.getOptionDurationYears())
-        sigma = float(self.annualisedVolatility) / 100.0
+        sigma = float(self.actualHistoricalVolatility) / 100.0
         sigma_squared_t = sigma**2 * t
         try:
             sigma_root_t = sigma * sqrt(t)
