@@ -34,28 +34,28 @@ class BlackScholesCallPricerTestCase(BlackScholesPricerTestCase):
 
 
 class TestBlackScholesCallPricer(BlackScholesCallPricerTestCase):
-    currentPrice = 10.0
+    lastPrice = 10.0
     expectedValue = 2.416
 
 class TestBlackScholesCallOnMoney(BlackScholesCallPricerTestCase):
-    currentPrice = 9.0
+    lastPrice = 9.0
     expectedValue = 1.7767
 
 class TestBlackScholesCallInMoney(BlackScholesCallPricerTestCase):
-    currentPrice = 20.0
+    lastPrice = 20.0
     expectedValue = 11.1534
 
 class TestBlackScholesCallOutMoney(BlackScholesCallPricerTestCase):
-    currentPrice = 3.0
+    lastPrice = 3.0
     expectedValue = 0.0125
 
 class TestBlackScholesCallLowRate(BlackScholesCallPricerTestCase):
-    currentPrice = 10.0
+    lastPrice = 10.0
     annualRiskFreeRate = 1.0
     expectedValue = 2.4597
 
 class TestBlackScholesCallHighRate(BlackScholesCallPricerTestCase):
-    currentPrice = 10.0
+    lastPrice = 10.0
     annualRiskFreeRate = 10.0
     expectedValue = 2.8644
 
@@ -63,28 +63,28 @@ class BlackScholesPutPricerTestCase(BlackScholesPricerTestCase):
     isPut = True
 
 class TestBlackScholesPutPricer(BlackScholesPutPricerTestCase):
-    currentPrice = 10.0
+    lastPrice = 10.0
     expectedValue = 1.416
 
 class TestBlackScholesPutOnMoney(BlackScholesPutPricerTestCase):
-    currentPrice = 9.0
+    lastPrice = 9.0
     expectedValue = 1.7767
 
 class TestBlackScholesPutOutMoney(BlackScholesPutPricerTestCase):
-    currentPrice = 20.0
+    lastPrice = 20.0
     expectedValue = 0.1534
 
 class TestBlackScholesPutInMoney(BlackScholesPutPricerTestCase):
-    currentPrice = 3.0
+    lastPrice = 3.0
     expectedValue = 6.0125
 
 class TestBlackScholesPutLowRate(BlackScholesPutPricerTestCase):
-    currentPrice = 10.0
+    lastPrice = 10.0
     annualRiskFreeRate = 1.0
     expectedValue = 1.3702
 
 class TestBlackScholesPutHighRate(BlackScholesPutPricerTestCase):
-    currentPrice = 10.0
+    lastPrice = 10.0
     annualRiskFreeRate = 10.0
     expectedValue = 1.0079
 
