@@ -17,10 +17,10 @@ class AbstractMonteCarloPricer(AbstractOptionPricer):
 
     def calcUnderlyings(self, draws):
         T = self.getOptionDurationYears()
-        sigma = float(self.annualisedVolatility) / 100
+        sigma = float(self.actualHistoricalVolatility) / 100
         sigma_root_T = sigma * sqrt(T)
         sigma_squared_T = sigma**2 * T
-        return self.currentPrice * exp(sigma_root_T * draws - 0.5 * sigma_squared_T)
+        return self.lastPrice * exp(sigma_root_T * draws - 0.5 * sigma_squared_T)
 
     def calcPayoffs(self, underlyings):
         if self.isPut:
