@@ -23,8 +23,8 @@ class TestEuropeanCall(MonteCarloPricerTestCase):
     pricerClass = EuropeanMonteCarloPricer
 
     strikePrice = 9
-    currentPrice = 10
-    annualisedVolatility = 50
+    lastPrice = 10
+    actualHistoricalVolatility = 50
     expectedValue = 2.416
 
 
@@ -34,8 +34,8 @@ class TestEuropeanPut(MonteCarloPricerTestCase):
     isPut = True
 
     strikePrice = 9
-    currentPrice = 10
-    annualisedVolatility = 50
+    lastPrice = 10
+    actualHistoricalVolatility = 50
     expectedValue = 1.416
 
 
@@ -44,8 +44,8 @@ class TestAmericanCall(MonteCarloPricerTestCase):
     pricerClass = AmericanMonteCarloPricer
 
     strikePrice = 9
-    currentPrice = 10
-    annualisedVolatility = 50
+    lastPrice = 10
+    actualHistoricalVolatility = 50
     expectedValue = 2.416
 
 
@@ -55,7 +55,7 @@ class TestAmericanPut(MonteCarloPricerTestCase):
     isPut = True
 
     strikePrice = 9
-    currentPrice = 10
-    annualisedVolatility = 50
+    lastPrice = 10
+    actualHistoricalVolatility = 50
     expectedValue = 1.416
 
